==> nextcloud-28.0.12.tgz: nextcloud/apps/notifications/l10n/ar.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "أهلاً %s",
    "Hello %s," : "أهلاً %s،",
    "_New notification for %s_::_%n new notifications for %s_" : ["%nإخطارات جديدة لـ%s","إخطار جديد لـ%s","%n إخطارات جديدة لـ %s","%n إخطارات جديدة لـ %s","%n إخطارات جديدة لـ %s","%nإخطارات جديدة لـ %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["لديك %n إخطارات جديدة لـ %s","لديك إخطار جديد لـ %s","لديك %n إخطارات جديدة لـ %s","لديك %n إخطارات جديدة لـ  %s","لديك %n إخطارات جديدة لـ %s ","لديك %n إخطارات جديدة لـ %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من  <a href=\"%s\"> الإعدادات </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من الإعدادات: %s",
    "Admin notifications" : "إشعارات المدير",
    "Notifications" : "الإشعارات",
    "Push notifications - Fair use policy" : "تحشيد الإشعارات - سياسة الاستعمال العادل",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "ترعى Nextcloud GmbH بوابة إشعارات دفع مجانية للمستخدمين الخاصين. لضمان خدمة جيدة، تحدد البوابة عدد إشعارات الدفع لكل خادم وتم الوصول إلى الحد الأقصى لهذا الخادم. بالنسبة لمستخدمي المؤسسات، تتوفر بوابة أكثر قابلية للتطوير.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "هذا التطبيق يوٌفر الواجهة و الخلفية لواجهة برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "هذا التطبيق يوٌفر الواجهة و الخلفية لمُدخل برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.\n\n\t\tتستغل التطبيقات المتعددة هذه الواجهة لإشعار المستخدم عبر الويب على الشاشة و كذلك لمزامنة تطبيق العميل حول أمورٍ عديدة؛ منها:\n📬ملفات تمّت مشاركتها معك من خوادم اتحادية remote share.\n📑 إشارات mentions إليك في كتابات المستخدمين الآخرين.\n🚢تحديثات updates مُتاحة للتطبيقات أو لنكست كلاود نفسه.\n📣إعلانات announcements إعلانات تبث عبر النظام بواسطة المدير.",
    "Failed to perform action" : "فشل في تنفيذ الإجراء",
    "Dismiss" : "رفض",
    "Contact Nextcloud GmbH" : "إتصل بشركة نكست كلاود",
    "seconds ago" : "ثوانٍ مضت",
    "Failed to dismiss notification" : "فشل في تجاهل إشعار",
    "in {path}" : "في {المسار}",
    "Dismiss all notifications" : "تجاهل كل الإشعارات",
    "Requesting browser permissions to show notifications" : "طلب إذن المُستعرِض للسماح بعرض الإشعارات",
    "Push notifications might be unreliable" : "الإشعارات المحشودة يمكن أن تكون غير موثوقة",
    "No notifications" : "لا توجد هناك إخطارات",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "ترعى شركة نكست كلاود بوابة مجانية لتحشيد الإشعارات للمستخدمين الخواص. و لضمان جودة الخدمة، تضع البوابة سقفاً على الإشعارات المجمعة لكل خادم. بالنسبة للمؤسسات، و للحصول على بوابة أكثر اعتمادية، يُرجى التواصل مع شركة نكست كلاود لمزيد التفاصيل.",
    "Failed to dismiss all notifications" : "فشل في تجاهل كل الإشعارات",
    "Notifications defaults" : "إفتراضات الإشعارات",
    "Configure the default notification settings for new users" : "تهيئة إعدادات الإشعارات الافتراضية للمستخدمين الجدد",
    "Send email reminders about unhandled notifications after:" : "أرسل إيميل تذكيري حول الإشعارات التي لم يتم تناولها بعدَ: ",
    "Play sound when a new notification arrives" : "أصدر تنبيه صوتي كلما وصل إشعار جديد",
    "Play sound when a call started (requires Nextcloud Talk)" : "أصدر تنبيه صوتي كلما بدأت مكالمة جديدة (يستلزم تطبيق نكست كلاود للمحادثة Talk)",
    "Never" : "أبدا",
    "1 hour" : "ساعة واحدة",
    "3 hours" : "3 ساعات",
    "1 day" : "1 يوم",
    "1 week" : "أسبوع واحد 1",
    "Your settings have been updated." : "تم تحديث إعداداتك.",
    "An error occurred while updating your settings." : "حدث خطأ أثناء تحديث إعداداتك.",
    "You need to set up your email address before you can receive notification emails." : "عليك إضافة بريدك الإلكتروني قبل تلقي رسائل الإشعارات.",
    "Also repeat sound on a secondary speaker" : "كرِّر الصوت كذلك على مكبر الصوت الثانوي",
    "Selection of the speaker device is currently not supported by Safari" : "إختيار جهاز مكبر الصوت غير مدعوم حاليّاً على مستعرض سافاري",
    "Select a device" : "إختَر جهازاً",
    "None" : "لا شيء"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-29.0.10.tgz: nextcloud/apps/notifications/l10n/ar.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "كان بودّنا أن نستمر في تقديم خدمة الإشعارات الفورية مجاناً، ولكن المستخدمين الكبار يرهقون بنيتنا الأساسية. ولهذا السبب يتعين علينا تحديد معدل استخدام للإشعارات الفورية. إذا كنت بحاجة إلى هذه الميزة، ففكر في استخدام Nextcloud Enterprise.",
    "User not found" : "المستخدم غير موجود",
    "The device does not seem to be supported" : "لا يبدو أن هذا الجهاز مدعوم",
    "An unexpected error occurred, ask your administration to check the logs." : "حدث خطأ غير متوقع. تواصل مع مشرفك لفحص سجل الحركات.",
    "Hello %s" : "أهلاً %s",
    "Hello %s," : "أهلاً %s،",
    "_New notification for %s_::_%n new notifications for %s_" : ["%nإخطارات جديدة لـ%s","إخطار جديد لـ%s","%n إخطارات جديدة لـ %s","%n إخطارات جديدة لـ %s","%n إخطارات جديدة لـ %s","%n إشعارات جديدة لـ %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["لديك %n إخطارات جديدة لـ %s","لديك إخطار جديد لـ %s","لديك %n إخطارات جديدة لـ %s","لديك %n إخطارات جديدة لـ  %s","لديك %n إخطارات جديدة لـ %s ","لديك %n إشعارات جديدة لـ %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من  <a href=\"%s\"> الإعدادات </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من الإعدادات: %s",
    "Admin notifications" : "إشعارات المدير",
    "Notifications" : "الإشعارات",
    "Push notifications - Fair use policy" : "تحشيد الإشعارات - سياسة الاستعمال العادل",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "ترعى Nextcloud GmbH بوابة إشعارات دفع مجانية للمستخدمين الخاصين. لضمان خدمة جيدة، تحدد البوابة عدد إشعارات الدفع لكل خادم وتم الوصول إلى الحد الأقصى لهذا الخادم. بالنسبة لمستخدمي المؤسسات، تتوفر بوابة أكثر قابلية للتطوير.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "هذا التطبيق يوٌفر الواجهة و الخلفية لواجهة برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "هذا التطبيق يوٌفر الواجهة و الخلفية لمُدخل برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.\n\n\t\tتستغل التطبيقات المتعددة هذه الواجهة لإشعار المستخدم عبر الويب على الشاشة و كذلك لمزامنة تطبيق العميل حول أمورٍ عديدة؛ منها:\n📬ملفات تمّت مشاركتها معك من خوادم اتحادية remote share.\n📑 إشارات mentions إليك في كتابات المستخدمين الآخرين.\n🚢تحديثات updates مُتاحة للتطبيقات أو لنكست كلاود نفسه.\n📣إعلانات announcements إعلانات تبث عبر النظام بواسطة المدير.",
    "Failed to perform action" : "فشل في تنفيذ الإجراء",
    "Dismiss" : "رفض",
    "Contact Nextcloud GmbH" : "إتصل بشركة نكست كلاود",
    "seconds ago" : "ثوانٍ مضت",
    "Failed to dismiss notification" : "فشل في تجاهل إشعار",
    "in {path}" : "في {المسار}",
    "Dismiss all notifications" : "تجاهل كل الإشعارات",
    "Requesting browser permissions to show notifications" : "طلب إذن متصفح الويب للسماح بعرض الإشعارات",
    "Push notifications might be unreliable" : "الإشعارات Push يمكن أن تكون غير موثوقة",
    "No notifications" : "لا توجد إشعارات",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "ترعى شركة نكست كلاود بوابة مجانية لتحشيد الإشعارات للمستخدمين الخواص. و لضمان جودة الخدمة، تضع البوابة سقفاً على الإشعارات المجمعة لكل خادم. بالنسبة للمؤسسات، و للحصول على بوابة أكثر اعتمادية، يُرجى التواصل مع شركة نكست كلاود لمزيد التفاصيل.",
    "Failed to dismiss all notifications" : "فشل في تجاهل كل الإشعارات",
    "Notifications defaults" : "إفتراضات الإشعارات",
    "Configure the default notification settings for new users" : "تهيئة إعدادات الإشعارات الافتراضية للمستخدمين الجدد",
    "Send email reminders about unhandled notifications after:" : "أرسل إيميل تذكيري حول الإشعارات التي لم يتم تناولها بعدَ: ",
    "Play sound when a new notification arrives" : "أصدر تنبيه صوتي كلما وصل إشعار جديد",
    "Play sound when a call started (requires Nextcloud Talk)" : "أصدر تنبيه صوتي كلما بدأت مكالمة جديدة (يستلزم تطبيق نكست كلاود للمحادثة Talk)",
    "Never" : "أبدا",
    "1 hour" : "ساعة واحدة",
    "3 hours" : "3 ساعات",
    "1 day" : "1 يوم",
    "1 week" : "أسبوع واحد 1",
    "Your settings have been updated." : "تم تحديث إعداداتك.",
    "An error occurred while updating your settings." : "حدث خطأ أثناء تحديث إعداداتك.",
    "You need to set up your email address before you can receive notification emails." : "عليك إضافة بريدك الإلكتروني قبل تلقي رسائل الإشعارات.",
    "Also repeat sound on a secondary speaker" : "كرِّر الصوت كذلك على مكبر الصوت الثانوي",
    "Selection of the speaker device is currently not supported by Safari" : "إختيار جهاز مكبر الصوت غير مدعوم حاليّاً على مستعرض سافاري",
    "Select a device" : "إختر جهازاً",
    "None" : "لا شيء"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
